;; Generated package description from gited.el
(define-package "gited" "0.3" "Operate on Git branches like dired" '((emacs "24.4") (cl-lib "0.5")) :url "http://elpa.gnu.org/packages/gited.html" :keywords '("git" "vc" "convenience"))
